Index: src/Fl_Input_.cxx
===================================================================
--- src/Fl_Input_.cxx	(revision 10022)
+++ src/Fl_Input_.cxx	(working copy)
@@ -428,37 +428,36 @@
 /**
   Finds the end of a word.
 
-  This call calculates the end of a word based on the given 
-  index \p i. Calling this function repeatedly will move
-  forwards to the end of the text.
- 
+  Return the index of the last byte of a space-separated word.
+  If the byte after \p i is a space, then the same value is returned.
+  Note that this is by byte, so the returned index may be in the middle
+  of a utf8 sequence.
+
   \param [in] i starting index for the search
   \return end of the word
 */
 int Fl_Input_::word_end(int i) const {
-  if (input_type() == FL_SECRET_INPUT) return size();
-  //while (i < size() && !isword(index(i))) i++;
-  while (i < size() && !isword(index(i))) i++;
-  while (i < size() && isword(index(i))) i++;
+  if (input_type() == FL_SECRET_INPUT)
+      return size();
+  while (i < size() && isword(index(i)))
+      i++;
   return i;
 }
 
 /**
   Finds the start of a word.
 
-  This call calculates the start of a word based on the given 
-  index \p i. Calling this function repeatedly will move
-  backwards to the beginning of the text.
- 
+  Return the index of the first byte of a space-separated word.
+  If the byte before \p i is a space, then the same value is returned.
+
   \param [in] i starting index for the search
   \return start of the word
 */
 int Fl_Input_::word_start(int i) const {
-  if (input_type() == FL_SECRET_INPUT) return 0;
-//   if (i >= size() || !isword(index(i)))
-//     while (i > 0 && !isword(index(i-1))) i--;
-  while (i > 0 && !isword(index(i-1))) i--;
-  while (i > 0 && isword(index(i-1))) i--;
+  if (input_type() == FL_SECRET_INPUT)
+      return 0;
+  while (i > 0 && isword(index(i-1)))
+      i--;
   return i;
 }
 
